<%-- $Id: exception.jsp 6309 2013-08-21 11:42:30Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	All exceptions are directed to this page, by the server configuration
	See <error-page> tag in the /WEB-INF/web.xml file.

	Some exceptions are fowarded to other pages to be able to
	display a more appropriate error message.

	Only severe, unexpected exceptions, are handled by this page,
	which will only display a stack trace!

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.Application"
	import="net.sf.basedb.core.Config"
	import="net.sf.basedb.core.NotLoggedInException"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.InvalidDataException"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.DuplicateWizardException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="javax.servlet.ServletException"
	import="java.sql.Driver"
	import="java.util.Properties"
	isErrorPage="true"
%>
<%@
	taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
	final SessionControl sc = Base.getSessionControl(pageContext, false);
	final String reportbuglink = sc == null ? "" : Values.getStringOrNull(sc.getClientDefaultSetting("server.links.reportbug"));
	Throwable ex = exception;
	
	if (ex instanceof org.apache.jasper.JasperException)
	{
		org.apache.jasper.JasperException jex = (org.apache.jasper.JasperException)ex;
		ex = jex.getRootCause();
	}
	
	if (ex instanceof ServletException)
	{
		ServletException sex = (ServletException)ex;
		if (sex.getRootCause() != null) ex = sex.getRootCause();
	}
	
	if (ex instanceof WebException)
	{
		pageContext.forward("/exception/web.jsp");
		return;
	}
	else if (ex instanceof DuplicateWizardException)
	{
		pageContext.forward("/exception/duplicate_wizard.jsp");
		return;
	}
	else if (ex instanceof NotLoggedInException)
	{
		pageContext.forward("/exception/not_logged_in.jsp");
		return;
	}
	else if (ex instanceof PermissionDeniedException)
	{
		pageContext.forward("/exception/permission_denied.jsp");
		return;
	}
	else if (ex instanceof InvalidDataException)
	{
		pageContext.forward("/exception/invalid_data.jsp");
		return;
	}

	final String jdbcDriver = Config.getString("db.driver");
	String driverVersion = "";
	try
	{
		final Driver driver = (Driver)Class.forName(jdbcDriver).newInstance();
		driverVersion = "(version " + driver.getMajorVersion() + "." + driver.getMinorVersion() + ")";
	}
	catch (Throwable t)
	{}	
	final Properties properties = System.getProperties();
	final Runtime runtime = Runtime.getRuntime();
	String exceptionClassName = ex.getClass().getName().replaceAll("net.sf.basedb.core.", "");
%>
<base:page type="default" menu="exception" title="Unexpected error">
<base:head scripts="exception.js" styles="popup.css" />
<base:body data-resize-if-popup="1">
	<h1><%=exceptionClassName + " on page "+request.getAttribute("javax.servlet.error.request_uri")%></h1>
	
	<div class="content bottomborder" style="bottom: 3em;">
		<table class="fullform outlined topborder">
		<tr>
			<th>BASE Version</th>
			<td><%=Application.getVersionString()%></td>
		</tr>
		<tr>
			<th>Web server</th>
			<td><%=application.getServerInfo()%></td>
		</tr>
		<tr>
			<th>Database Server</th>
			<td><%=Application.getDatabaseVersionString()%></td>
		</tr>
		<tr>
			<th>Database Dialect</th>
			<td><%=Config.getString("db.dialect")%></td>
		</tr>
		<tr>
			<th>JDBC Driver</th>
			<td><%=jdbcDriver%> <%=driverVersion%></td>
		</tr>
		<tr>
			<th>Operating system</th>
			<td><%=properties.getProperty("os.name")%> 
				<%=properties.getProperty("os.arch")%>
				<%=properties.getProperty("os.version")%>
				</td>
		</tr>
		<tr>
			<th>Java runtime</th>
			<td><%=properties.getProperty("java.runtime.name")%> 
				(<%=properties.getProperty("java.runtime.version")%>), 
				<a href="<%=properties.getProperty("java.vendor.url")%>" target="_blank"><%=properties.getProperty("java.vendor")%></a></td>
		</tr>
		<tr>
			<th class="subprompt">Memory</th>
			<td>Total: <%=Values.formatBytes(runtime.totalMemory())%><br>
				Free: <%=Values.formatBytes(runtime.freeMemory()) %><br>
				Max: <%=Values.formatBytes(runtime.maxMemory()) %></td>
		</tr>
		<tr>
			<th>Browser</th>
			<td><%=HTML.encodeTags(request.getHeader("User-Agent"))%></td>
		</tr>
		<tr>
			<th>Error message</th>
			<td><%=HTML.formatLineBreaks(HTML.encodeTags(ex.getMessage(), ""))%></td>
		</tr>
		<tr class="dynamic">
			<th>Stacktrace</th>
			<td>
				<%
				StackTraceElement[] st = ex.getStackTrace();
				out.println("<pre>");
				out.println(exceptionClassName);
				int i = 0;
				for (i=0; i < st.length && i < 8; i++)
				{
					out.print("...at ");
					out.println(HTML.encodeTags(st[i].toString().replaceAll("net.sf.basedb.core.", "")));
				}
				out.println("</pre>");
				if ((i < st.length) || (ex.getCause() != null))
				{
					out.println("<pre id=\"error_detail\" style=\"display:none;\">");
					while (ex != null)
					{
						for (int j=i; j < st.length; j++)
						{
							out.print("...at ");
							out.println(HTML.encodeTags(st[j].toString().replaceAll("net.sf.basedb.core.", "")));
						}
						ex = ex.getCause();
						if (ex != null)
						{
							st = ex.getStackTrace();
							i = 0;
							out.print("\nCaused by: "+ex.getClass().getName()+": " + ex.getMessage() + "\n");
						}
					}
					out.println("</pre>");
				}
				%>
				<base:icon 
					id="showMoreDetails"
					data-show-id="error_detail"
					image="gonext.png"><%=st.length-i%> more...</base:icon>
			</td>
		</table>
	</div>
	
	<base:buttongroup subclass="dialogbuttons">
		<base:button id="goback" title="Back"/>
		<base:button id="close" title="Close"/>
		<base:button id="reportbug" title="Report bug&hellip;" image="bug.png"
			data-report-link="<%=HTML.encodeTags(reportbuglink) %>"
			visible="<%=HTML.isValidUrl(reportbuglink)%>"/>
	</base:buttongroup>

</base:body>
</base:page>

