<%-- $Id: not_logged_in.jsp 6426 2014-02-27 09:37:49Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	This page is used to catch NotLoggedInExceptions which are
	directed here via the exception.jsp page. NotLoggedInExceptions
	happen when a user tries to access a protected page without beeing
	logged in. Typically the exception is thrown from the method that
	retrieves the BaseControl object:

	BASE.getExistingBaseControl(pageContext);

	This page will display a new login form allowing the user
	to login again and continue with what he/she was doing.

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.Application"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.login.LoginFormAction"
	import="net.sf.basedb.clients.web.extensions.login.LoginFormBean"
	import="net.sf.basedb.clients.web.extensions.login.FieldInfo"
	isErrorPage="true"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%! 
// If value is null, return "", else <prefix>+<value>+<suffix>
String valueIfNotNull(String prefix, String value, String suffix)
{
	return value == null ? "" : prefix+value+suffix;
}
%>
<%
final SessionControl sc = Base.getSessionControl(pageContext, true);
final String ID = sc.getId();
final String root = request.getContextPath()+"/";
final String redirect = Values.getString((String)request.getAttribute("redirect"));
final DbControl dc = sc.newDbControl();

try
{
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext);
	ExtensionsInvoker<LoginFormAction> invoker = (ExtensionsInvoker<LoginFormAction>)ExtensionsControl.useExtensions(jspContext, "net.sf.basedb.clients.web.login-form");
	LoginFormAction loginAction = null;
	for (LoginFormAction action : invoker)
	{
		if (action != null)
		{
			loginAction = action;
			break;
		}
	}
	if (loginAction == null)
	{
		LoginFormBean bean  = new LoginFormBean();
		bean.setRememberLastLogin(true);
		bean.setLoginField(FieldInfo.DEFAULT_LOGIN);
		bean.setPasswordField(FieldInfo.DEFAULT_PASSWORD);
		loginAction = bean;
	}
	FieldInfo loginField = loginAction.getLoginField();
	FieldInfo passwordField = loginAction.getPasswordField();
	%>
	<base:page type="default" menu="exception" title="Not logged in">
	<base:head scripts="exception.js,/login.js" styles="login.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body data-resize-if-popup="1">
	
			<form action="<%=root%>login.jsp?again=1" method="post" name="login" target="Login">
			<input type="hidden" name="ID" value="<%=ID%>">
			<input type="hidden" name="redirect" value="<%=redirect%>">
	
			<table style="margin: auto; width: 640px; margin-top:5em; ">
			<tr>
			<td>
				<%
				if (loginAction.getHelp() != null)
				{
					%>
					<div class="messagecontainer help" style="font-style: italic;" id="login-help">
					<%=loginAction.getHelp() %>
					</div>
					<%
				}
				%>
				<table style="width: 100%;">
				<tr>
					<td style="background-color: #000000; border-radius: 4px 0px 0px 4px; width: 125px;"><img src="<%=root%>images/baselogo.png" alt="BASE logo"></td>
					<td style="width: 515px;">
						<div id="loginform">
						<table style="width: 100%;">
							<tr <%=valueIfNotNull("class=\"", loginField.getClazz(), "\"")%> id="login-row">
								<th><%=loginField.getPrompt() %></th>
								<td colspan="2"><input class="text" name="login" id="login"
									type="<%=loginField.hasHiddenCharacters() ? "password" : "text"%>"
									value="" 
									<%=valueIfNotNull("style=\"", loginField.getStyle(), "\"") %>
									<%=valueIfNotNull("title=\"", loginField.getTooltip(), "\"") %>
									<%=valueIfNotNull("placeholder=\"", loginField.getPlaceHolder(), "\"") %>
									<%=loginAction.rememberLastLogin() ? "" : "autocomplete=\"off\" data-use-last-login=\"0\""%>
									maxlength="100"	
									tabindex="0">
								</td>
							</tr>
							<tr <%=valueIfNotNull("class=\"", passwordField.getClazz(), "\"")%> id="password-row">
								<th><%=passwordField.getPrompt() %></th>
								<td><input class="text" name="password" id="password"
									type="<%=passwordField.hasHiddenCharacters() ? "password" : "text"%>"
									<%=valueIfNotNull("style=\"", passwordField.getStyle(), "\"") %>
									<%=valueIfNotNull("title=\"", passwordField.getTooltip(), "\"") %>
									<%=valueIfNotNull("placeholder=\"", passwordField.getPlaceHolder(), "\"") %>
									maxlength="80"
									tabindex="0">
								</td>
								<td>
									<base:buttongroup>
										<base:button id="btnLogin" image="login.png" title="Login" />
										<base:button id="close" title="Cancel" />
									</base:buttongroup>
								</td>
							</tr>
							<tr>
								<th></th>
								<td colspan="2">
								<%
								String forgotPassword = sc.getClientDefaultSetting("server.forgotten.password");
								String getAccount = sc.getClientDefaultSetting("server.get.account");
								if (forgotPassword != null)
								{
									%>
									<base:icon id="forgotPassword" image="bullet.png" 
										tooltip="Click here if you have forgotten your password">Forgot your password?</base:icon>
									<%
								}
								if (getAccount != null)
								{
									%>
									<base:icon id="getAccount" image="bullet.png" 
										tooltip="Click here if you want to get an account on this server">Get an account!</base:icon>
									<%
								}
								%>
								</td>
							</tr>
							</table>
						</div>
					</td>
				</tr>
				</table>
	
				<div class="messagecontainer error" id="timeout" style="display: none;">
					<b>Not logged in</b><br>
					You have been automatically logged out due to inactivity or because the 
					server has been restarted.
					You may log in again and continue your work but unsaved changes 
					may have been lost.
				</div>
	
			</td>
			</tr>
			</table>
	
		</form>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
