/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var ArrayDesigns = function()
{
	var arrayDesigns = {};
	
	/**
		Initialize the page.
	*/
	arrayDesigns.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', arrayDesigns.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', Annotations.autoLoadEditFrame);
			TabControl.addTabActivateListener('settings.inheritedAnnotations', Annotations.autoLoadInheritFrame);
			TabControl.addTabActivateListener('settings.datafiles', arrayDesigns.loadDataFilesFrame);
			TabControl.addTabValidator('settings.info', arrayDesigns.validateArrayDesign);
			
			// Num arrays
			Events.addEventHandler('numArrays', 'keypress', Events.integerOnly);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'ARRAYDESIGN', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnNewBatch', arrayDesigns.newBatch, attributes);
			Buttons.addClickHandler('btnManagePlates', arrayDesigns.managePlates);

			TabControl.addTabActivateListener('main.features', arrayDesigns.viewFeatures);
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.overview', Overview.loadOnce);
			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'ARRAYDESIGN'};
			var tableAttributes = {'table-id': 'designs'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
		
	arrayDesigns.initElements = function(element, autoInit)
	{
		if (autoInit == 'new-batch')
		{
			Buttons.addClickHandler(element, arrayDesigns.newBatch);
		}
	}
	
	arrayDesigns.newBatch = function(event)
	{
		var designId = Data.get(event.currentTarget, 'item-id');
		Items.newItem('ARRAYBATCH', '&arraydesign_id='+designId);
	}

	
	arrayDesigns.managePlates = function()
	{
		var itemId = Data.get('page-data', 'item-id');
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=ManagePlates&item_id='+itemId;
		Dialogs.openPopup(url, 'ManagePlates', 600, 400);
	}
	
	arrayDesigns.viewFeatures = function()
	{
		var designId = Data.get('page-data', 'item-id');
		var url = 'features/index.jsp?ID='+App.getSessionId();
		url += '&cmd=List&arraydesign_id='+designId;
		location.replace(url);
	}

	arrayDesigns.validateArrayDesign = function()
	{
		var frm = document.forms['design'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		else if (!Numbers.isInteger(frm.numArrays.value))
		{
			Forms.showNotification(frm.numArrays, "'" + frm.numArrays.value + "' is not a valid number");
			return false;
		}
		else if (parseInt(frm.numArrays.value) <= 0)
		{
			Forms.showNotification(frm.numArrays, "Number of arrays must be &gt;0");
			return false;
		}
		return true;
	}

	arrayDesigns.save = function()
	{
		var frm = document.forms['design'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			Annotations.saveInheritedAnnotationsToForm(frm);
			DataFiles.writeFileActionsToForm(frm);
			frm.submit();
		}
	}
	
	arrayDesigns.loadDataFilesFrame = function()
	{
		var frm = document.forms['design'];
		var selected = frm.platform[frm.platform.selectedIndex];
		var platform = Data.get(selected, 'platform');
		var variant = Data.get(selected, 'variant');
		DataFiles.autoLoadEditFrame(platform ? platform : 0, variant ? variant : 0, 0);
	}

	
	return arrayDesigns;
}();

Doc.onLoad(ArrayDesigns.initPage);
Doc.addElementInitializer(ArrayDesigns.initElements);
